@@ -1,11 +1,11 @@
 package ValidatorPackagesTest2;
 
-sub match_multi_validator_success_expected {
+sub valid_multi_validator_success_expected {
 	my $val = shift;
 	return 1;
 }
 
-sub match_multi_validator_failure_expected {
+sub valid_multi_validator_failure_expected {
 	return undef;
 }
 
